@@ -18,14 +18,6 @@ class FfmpegRecordThread(threading.Thread):
         :param timeout: 超时断开连接，设定时间，默认5s,单位为微妙级
         :param kwargs:
         """
-        self.create_time = datetime.now()
-        self.name = name
-        self.stream_url = stream_url
-        self.out_file_path = out_file_path
-        self.out_file_dir = os.path.split(out_file_path)[0]
-        self.video_duration = video_duration
-        self.file_name_out_list = os.path.join(self.out_file_dir, name + '.txt')
-
         sub_shell = ''
         if 'rtsp_transport' in kwargs:
             sub_shell = '-rtsp_transport {} '.format(kwargs.pop('rtsp_transport'))
@@ -36,6 +28,14 @@ class FfmpegRecordThread(threading.Thread):
 
         super(FfmpegRecordThread, self).__init__(**kwargs)
 
+        self.create_time = datetime.now()
+        self.name = name
+        self.stream_url = stream_url
+        self.out_file_path = out_file_path
+        self.out_file_dir = os.path.split(out_file_path)[0]
+        self.video_duration = video_duration
+        self.file_name_out_list = os.path.join(self.out_file_dir, name + '.txt')
+
 
         self.shell_cmd_mp4 = (
             'ffmpeg '
@@ -43,7 +43,7 @@ class FfmpegRecordThread(threading.Thread):
             '-v info '
             '-rtbufsize 1m '
             '{sub_shell}'                                      # 超时断开连接，设定是5s
-            '-i {stream_url} '                        # 输入视频文件或流等其他
+            '-i "{stream_url}" '                        # 输入视频文件或流等其他
             '-movflags faststart+frag_keyframe '      # 使mp4支持渐进式下载
             '-c:v copy '                              # 原始编解码数据必须被拷贝
             '-c:a copy '                              # 设定声音编码，降低CPU使用
@@ -52,11 +52,11 @@ class FfmpegRecordThread(threading.Thread):
             '-strftime 1 '                            # 设置切片名为生成切片的时间点
             '-segment_time {segment_time} '           # 流切分时长
             '-reset_timestamps 1 '                    # 每个切片都重新初始化时间戳
-            '-segment_list {file_name_out_list} '     # 切片列表主文件名，输入是在文件写入完成之后
+            '-segment_list "{file_name_out_list}" '     # 切片列表主文件名，输入是在文件写入完成之后
             '-segment_list_size 10 '                  # 列表文件长度
-            '-segment_list_entry_prefix {out_path} '  # 写文件列表时写入每个切片路径的前置路径
+            '-segment_list_entry_prefix "{out_path}" '  # 写文件列表时写入每个切片路径的前置路径
 
-            '{out_file} '                             # 输出文件名
+            '"{out_file}" '                             # 输出文件名
         ).format(sub_shell=sub_shell,
                  stream_url=self.stream_url,
                  segment_time=video_duration,
